@@ -17,7 +17,7 @@ use memoffset::offset_of;
 use rusty_d3d12::*;
 
 #[no_mangle]
-pub static D3D12SDKVersion: u32 = 4;
+pub static D3D12SDKVersion: u32 = 600;
 
 #[no_mangle]
 pub static D3D12SDKPath: &[u8; 9] = b".\\D3D12\\\0";
@@ -262,12 +262,12 @@ impl DynamicIndexingSample {
         let info_queue = Rc::new(
             InfoQueue::new(
                 &device,
-                Some(&[
-                    MessageSeverity::Corruption,
-                    MessageSeverity::Error,
-                    MessageSeverity::Warning,
-                ]),
-                // None,
+                // Some(&[
+                //     MessageSeverity::Corruption,
+                //     MessageSeverity::Error,
+                //     MessageSeverity::Warning,
+                // ]),
+                None,
             )
             .expect("Cannot create debug info queue"),
         );
